@@ -511,7 +511,7 @@ gnome_rr_config_load_current (GnomeRRConfig *config, GError **error)
 	GnomeRROutput *rr_output = rr_outputs[i];
 	GnomeRROutputInfo *output = g_object_new (GNOME_TYPE_RR_OUTPUT_INFO, NULL);
 	GnomeRRMode *mode = NULL;
-	const guint8 *edid_data = gnome_rr_output_get_edid_data (rr_output);
+	const guint8 *edid_data = gnome_rr_output_get_edid_data (rr_output, NULL);
 	GnomeRRCrtc *crtc;
 
 	output->priv->name = g_strdup (gnome_rr_output_get_name (rr_output));
@@ -690,7 +690,8 @@ gnome_rr_config_load_filename (GnomeRRConfig *result, const char *filename, GErr
 
 		array = g_ptr_array_new ();
 		for (j = 0; configs[i]->priv->outputs[j] != NULL; j++) {
-		    g_ptr_array_add (array, configs[i]->priv->outputs[i]);
+                    g_object_ref (configs[i]->priv->outputs[j]);
+		    g_ptr_array_add (array, configs[i]->priv->outputs[j]);
 		}
 		g_ptr_array_add (array, NULL);
 		result->priv->outputs = (GnomeRROutputInfo **) g_ptr_array_free (array, FALSE);
@@ -1227,7 +1228,8 @@ gnome_rr_config_ensure_primary (GnomeRRConfig *configuration)
         if (!found) {
                 if (laptop != NULL) {
                         laptop->priv->primary = TRUE;
-                } else {
+                } else if (top_left != NULL) {
+                        /* Note: top_left can be NULL if all outputs are off */
                         top_left->priv->primary = TRUE;
                 }
         }
